-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local lower = string.lower
local addonName, addonTable = ...
local AddColor = addonTable.AddColor
local quest = DailyGlobalCheck.QuestFunctions

local instance_names = {}

-- special quests completion
-- instance
function quest.instance(instanceID, diff)

 if not instanceID or not diff then return end

 local now = time()
 for i = 1, GetNumSavedInstances() do
  local name, _, reset, difficulty, locked, extended, _, isRaid, _, difficultyName, numEncounters, encounterProgress = GetSavedInstanceInfo(i)
  local link = GetSavedInstanceChatLink(i) or ""
  local ID = link:find(":"..instanceID..":")
  if ID and (diff == "all" or difficulty == tonumber(diff)) then
   if (locked or extended) then
    return true, AddColor(encounterProgress.." / "..numEncounters, "LIGHT_GREEN"), reset
   else
    return true, AddColor("["..LFG_LIST_APP_TIMED_OUT.."] "..encounterProgress.." / "..numEncounters, "GRAY"), now + 864000
   end
  end
 end
end
-- instance boss
function quest.boss(instanceID, diff, boss)
 if not instanceID or not diff then return end

 local now = time()
 for i = 1, GetNumSavedInstances() do
  local name, _, reset, difficulty, locked, extended, _, isRaid, _, difficultyName, numEncounters, encounterProgress = GetSavedInstanceInfo(i)
  local link = GetSavedInstanceChatLink(i) or ""
  local ID = link:find(":"..instanceID..":")
  if ID and (diff == "all" or difficulty == tonumber(diff)) then
   if (locked or extended) then
    local _, _, dead = GetSavedInstanceEncounterInfo(i, boss)
	if dead then	 
     return true, BOSS_DEAD, reset
	end
   end
  end
 end
 return false, AVAILABLE
end
--

-- currency
function quest.currency(currencyID)
 local name, amount, texturePath, earnedThisWeek, weeklyMax, totalMax, isDiscovered = GetCurrencyInfo(currencyID)
 local now = time()
 return true, amount.." / "..totalMax, now + 2592000
end
--
-- achievement criteria
function quest.achicriteria(achiID, criteria)
 local id, _, _, completed = GetAchievementInfo(achiID)

 if not id or not criteria then return false, BLIZZARD_STORE_REGION_LOCKED end

 return completed or select(3, GetAchievementCriteriaInfo(achiID, criteria))
end
--
-- handler
function quest:isquestcompleted(questID)
 local key,arg1,arg2,arg3 = strsplit("#", questID)
 
 if not key then return false end

 key = lower(key)
 
 if quest[key] and type(quest[key]) == "function" then
  return quest[key](arg1, arg2, arg3)
 end
end

-- Overlay
function quest:GetOverlayInfo(questID)
 local qData = DailyGlobalCheck:getQData(questID)

 if not qData then return end
 
  -- it's an alt
 if DailyGlobalCheck.selectedpID ~= addonTable.pID then
  local c = DailyGlobalCheck_CharData[DailyGlobalCheck.selectedpID]
  if not c or not c.data or not c.data[questID] then return end
  local _, _, link = strsplit("~", c.data[questID])
  if link == "" or link == "nil" then link = nil end
  if link then
   local t = {strsplit("^", link)}
  end
  return link
 end
 
 local result
 questID = tostring(questID)

 -- it's the player
 if questID:find("instance#") then -- instance
  local key,arg1,arg2 = strsplit("#", questID)
  for i = 1, GetNumSavedInstances() do
   local name, _, reset, difficulty, locked, extended = GetSavedInstanceInfo(i)
   local link = GetSavedInstanceChatLink(i) or ""
   local ID = link:find(":"..arg1..":")
   if --[[(locked or extended) and ]]ID and (arg2 == "all" or difficulty == tonumber(arg2)) then
    result = link
   end
  end
 else -- overlay data (array of strings)
  result = qData[13]
 end
 return result
end

local function showTooltip(data)
 GameTooltip:SetOwner(DGC_Mainframe, "ANCHOR_NONE")
 GameTooltip:SetPoint("LEFT", DGC_Mainframe, "RIGHT")
 GameTooltip:ClearLines()
 
 --local result = quest:GetOverlayInfo(questID)
 local t = type(data)
 
 if t == "string" then
  GameTooltip:SetHyperlink(data)
 elseif t == "table" then
  for _,v in pairs(data) do
   GameTooltip:AddLine(v)
  end
 end
 GameTooltip:Show()
end

function quest:ShowOverlay(button)
 showTooltip(button.overlayInfo)
end

function quest:HideOverlay(button)
 GameTooltip:Hide()
end